# amdi18n-loader

Webpack i18n loader similar to require.js i18n plugin.

## Install

```sh
npm install amdi18n-loader
```

## Usage

First look at require.js i18n plugin's docs [at here](http://requirejs.org/docs/api.html#i18n).

The language part is like this:

- `lang.js`
- `zh-cn/lang.js`
- `zh-hk/lang.js`

lang.js:

```javascript
define({
    // root means the common language package
    root:{
        HELLO:'hello'
    },
    // we have the language packages below:
    'zh-cn':true,
    'zh-hk':true
});
```

zh-cn/lang.js example:

```javascript
define({
    // please note: no wrapper object here!
    HELLO:'hello in zh-cn'
});
```

Then use it like this:

```javascript
define([
    'amdi18n!lang'
],function(amdi18n){

    // the key difference from require.js i18n plugin
    // because require.js code is run in runtime
    // so the language is specified by `require.config`
    // but in webpack, we have no way to specify language
    // in runtime, so we have to manully init
    //
    // you can pass a language in, if nothing is passed,
    // it will lookup `window._i18n._locale`,
    // if nothing found, `root` was used.

    amdi18n.init();

    console.log(amdi18n.HELLO);

    // amdi18n.init([language]);

});
```
